# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: allegoserver.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import datasource_pb2 as datasource__pb2
from . import biointerface_pb2 as biointerface__pb2
from . import spikesorter_pb2 as spikesorter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='allegoserver.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x12\x61llegoserver.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x10\x64\x61tasource.proto\x1a\x12\x62iointerface.proto\x1a\x11spikesorter.proto\"4\n\x0eRestartRequest\x12\"\n\x04mode\x18\x01 \x02(\x0e\x32\x14.allego.BackboneMode\":\n\x11SetProfileRequest\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\x12\x0b\n\x03\x64ur\x18\x03 \x02(\x02\"\xe9\x02\n\x10LogSystemRequest\x12\x34\n\x04mode\x18\x01 \x02(\x0e\x32&.allego.LogSystemRequest.LogSystemMode\x12=\n\x07outMode\x18\x02 \x01(\x0e\x32,.allego.LogSystemRequest.LogSystemOutputMode\x12\x16\n\x0eoutPathAndFile\x18\x03 \x01(\t\"|\n\rLogSystemMode\x12\n\n\x06\x63onfig\x10\x00\x12\n\n\x06status\x10\x01\x12\x0c\n\x08port_map\x10\x02\x12\n\n\x06pcache\x10\x03\x12\x0c\n\x08sigstats\x10\x04\x12\x11\n\rneurons_stats\x10\x06\x12\x18\n\x14\x62\x61se_signalgroup_map\x10\x07\"J\n\x13LogSystemOutputMode\x12\x12\n\x0eLOG_OUT_STDERR\x10\x00\x12\x0f\n\x0bLOG_OUT_CSV\x10\x01\x12\x0e\n\nLOG_OUT_MD\x10\x02\"4\n\x10SetStreamRequest\x12 \n\x04mode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\"4\n\x10SetRecordRequest\x12 \n\x04mode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\"~\n\x14SetConfigCoreRequest\x12\x10\n\x08sampFreq\x18\x01 \x01(\x01\x12\x0f\n\x07loopDur\x18\x02 \x01(\x01\x12\x19\n\x11pcachePersistence\x18\x03 \x01(\x01\x12(\n\x0b\x63\x61\x62leLength\x18\x04 \x01(\x0b\x32\x13.allego.CableLength\">\n\x0b\x43\x61\x62leLength\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x13\n\x0b\x63\x61\x62leLength\x18\x02 \x02(\x01\"f\n\x0c\x43\x61\x62leLengths\x12\t\n\x01\x41\x18\x01 \x02(\x01\x12\t\n\x01\x42\x18\x02 \x02(\x01\x12\t\n\x01\x43\x18\x03 \x02(\x01\x12\t\n\x01\x44\x18\x04 \x02(\x01\x12\t\n\x01\x45\x18\x05 \x02(\x01\x12\t\n\x01\x46\x18\x06 \x02(\x01\x12\t\n\x01G\x18\x07 \x02(\x01\x12\t\n\x01H\x18\x08 \x02(\x01\"\xb1\x01\n\nConfigCore\x12\x1c\n\x14\x61llegoCoreServerPort\x18\x01 \x02(\t\x12\x14\n\x0c\x62\x61seSampFreq\x18\x03 \x02(\x01\x12\x17\n\x0fstreamLoopDurMs\x18\x04 \x02(\x05\x12*\n\x0c\x63\x61\x62leLengths\x18\x05 \x02(\x0b\x32\x14.allego.CableLengths\x12*\n\x0c\x62\x61\x63kboneMode\x18\x06 \x02(\x0e\x32\x14.allego.BackboneMode\"r\n\x0fRecordingStatus\x12&\n\nrecordMode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\x12\x16\n\x0e\x61\x63tiveFileName\x18\x02 \x02(\t\x12\x10\n\x08\x64uration\x18\x03 \x02(\x01\x12\r\n\x05\x65rror\x18\x04 \x02(\t\"r\n\x0fStreamingStatus\x12&\n\nstreamMode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\x12\x1a\n\x12primaryCacheTRange\x18\x02 \x03(\x01\x12\x1b\n\x13hardwareMemoryLevel\x18\x03 \x02(\x01\"\xda\x01\n\x0e\x42\x61\x63kboneStatus\x12*\n\tstreaming\x18\x01 \x02(\x0b\x32\x17.allego.StreamingStatus\x12*\n\trecording\x18\x02 \x02(\x0b\x32\x17.allego.RecordingStatus\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x12\x13\n\x0bisConnected\x18\x04 \x02(\x08\x12\x32\n\x10gpioChannelCount\x18\x05 \x02(\x0b\x32\x18.allego.GPIOChannelCount\"\xc9\x02\n\x0f\x43onfigAndStatus\x12*\n\tstreaming\x18\x01 \x02(\x0b\x32\x17.allego.StreamingStatus\x12*\n\trecording\x18\x02 \x02(\x0b\x32\x17.allego.RecordingStatus\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x12\x13\n\x0bisConnected\x18\x04 \x02(\x08\x12\x32\n\x10gpioChannelCount\x18\x05 \x02(\x0b\x32\x18.allego.GPIOChannelCount\x12\x14\n\x0c\x62\x61seSampFreq\x18\x06 \x02(\x01\x12*\n\x0c\x63\x61\x62leLengths\x18\x07 \x02(\x0b\x32\x14.allego.CableLengths\x12*\n\x0c\x62\x61\x63kboneMode\x18\x08 \x02(\x0e\x32\x14.allego.BackboneMode\"g\n\x0f\x43onfigRecording\x12\x14\n\x0c\x62\x61seFileName\x18\x01 \x02(\t\x12\x14\n\x0c\x62\x61seFilePath\x18\x02 \x02(\t\x12\x15\n\rdataSourceIdx\x18\x03 \x01(\x05\x12\x11\n\ttimeStamp\x18\x04 \x01(\x08\"V\n\x14\x44IOModeEventsRequest\x12\x0f\n\x07\x63hanIdx\x18\x02 \x02(\x05\x12\x16\n\x0e\x65ventThreshold\x18\x03 \x02(\x01\x12\x15\n\reventPolarity\x18\x04 \x02(\x08\"6\n\x14\x44IOModeManualRequest\x12\x0f\n\x07\x63hanIdx\x18\x01 \x02(\x05\x12\r\n\x05state\x18\x02 \x02(\x08\"s\n\x19\x44igitalOutChannelRegister\x12\x13\n\x0bmanualState\x18\x01 \x02(\x08\x12\x16\n\x0e\x65ventThreshold\x18\x02 \x02(\x01\x12\x15\n\reventPolarity\x18\x03 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x04 \x02(\x05\"q\n\x12\x44igitalOutRegister\x12\x1d\n\x04mode\x18\x01 \x02(\x0e\x32\x0f.allego.DIOMode\x12<\n\x11\x64outChanRegisters\x18\x02 \x03(\x0b\x32!.allego.DigitalOutChannelRegister\"\x1e\n\x0e\x44\x41\x43GainRequest\x12\x0c\n\x04gain\x18\x01 \x02(\x05\"w\n\x18\x41nalogOutChannelRegister\x12\x15\n\rPriNtvChanIdx\x18\x01 \x02(\x05\x12\x1b\n\x13\x41nalogOutNtvChanIdx\x18\x02 \x02(\x05\x12\x0e\n\x06Stream\x18\x03 \x02(\x05\x12\x17\n\x0fStreamOffsetIdx\x18\x04 \x02(\x05\"^\n\x11\x41nalogOutRegister\x12;\n\x11\x61nalogOutChannels\x18\x01 \x03(\x0b\x32 .allego.AnalogOutChannelRegister\x12\x0c\n\x04gain\x18\x02 \x02(\x05\"!\n\x0cSerialNumber\x12\x11\n\tserialNum\x18\x01 \x02(\t\"\x81\x01\n\x12SetSimPortsRequest\x12\x33\n\x07simPort\x18\x01 \x03(\x0b\x32\".allego.SetSimPortsRequest.SimPort\x1a\x36\n\x07SimPort\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07numChan\x18\x02 \x02(\x03\"\'\n\x14SetMuxChannelRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\x03\"\'\n\x14SetPotVoltageRequest\x12\x0f\n\x07voltage\x18\x01 \x02(\x02\"!\n\x10GetADCLevelReply\x12\r\n\x05level\x18\x01 \x02(\x02\"#\n\x12SetPotRangeRequest\x12\r\n\x05range\x18\x01 \x02(\x05\"!\n\x11SetPotModeRequest\x12\x0c\n\x04mode\x18\x01 \x02(\x08\")\n\x17SetPotCellEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x02(\x08\",\n\x12ReadWireOutRequest\x12\x16\n\x0ewireOutAddress\x18\x01 \x02(\x03\"(\n\x10ReadWireOutReply\x12\x14\n\x0cwireOutValue\x18\x01 \x02(\x03\"\xc7\x02\n\x11LogsysConfigReply\x12(\n\nsystemMode\x18\x01 \x02(\x0e\x32\x14.allego.BackboneMode\x12\x14\n\x0c\x62\x61seSampFreq\x18\x02 \x02(\x01\x12\x17\n\x0fstreamLoopDurMs\x18\x03 \x02(\x05\x12\x1a\n\x12priCachePersistDur\x18\x04 \x02(\x01\x12!\n\x19priCacheStatsUpdatePeriod\x18\x05 \x02(\x01\x12\x12\n\nactiveSigs\x18\x06 \x02(\x05\x12\x10\n\x08priChans\x18\x07 \x02(\x05\x12\x10\n\x08\x61uxChans\x18\x08 \x02(\x05\x12\x10\n\x08\x64inChans\x18\t \x02(\x05\x12\x11\n\tdoutChans\x18\n \x02(\x05\x12\"\n\x08portSpec\x18\x0b \x03(\x0b\x32\x10.allego.PortInfo\x12\x19\n\x11numConnectedPorts\x18\x0c \x02(\x05\"Y\n\x08PortInfo\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\r\n\x05probe\x18\x02 \x02(\t\x12\x11\n\theadstage\x18\x03 \x02(\t\x12\x0f\n\x07numSigs\x18\x04 \x02(\x05\"c\n\x11LogsysStatusReply\x12\'\n\x07recStat\x18\x01 \x02(\x0b\x32\x16.allego.RecorderStatus\x12%\n\x07sysStat\x18\x02 \x02(\x0b\x32\x14.allego.SystemStatus\"\xba\x01\n\x0eRecorderStatus\x12&\n\nrecordMode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\x12\x10\n\x08\x64uration\x18\x02 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\x03 \x02(\x01\x12\x11\n\tsizeBytes\x18\x04 \x02(\x05\x12\x0c\n\x04path\x18\x05 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x06 \x02(\t\x12\x15\n\rdataSourceIdx\x18\x07 \x02(\x05\x12\x16\n\x0e\x61\x63tiveFileName\x18\x08 \x02(\t\"\x96\x03\n\x0cSystemStatus\x12&\n\nstreamMode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\x12\x14\n\x0c\x62\x61seSampFreq\x18\x02 \x02(\x01\x12\x12\n\nnumPriSigs\x18\x03 \x02(\x05\x12\x12\n\nnumAuxSigs\x18\x04 \x02(\x05\x12\x12\n\nnumDinSigs\x18\x05 \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x06 \x02(\x05\x12\x13\n\x0btStampRange\x18\x07 \x03(\x03\x12\x0e\n\x06tRange\x18\x08 \x03(\x01\x12\x11\n\tstreamDur\x18\t \x02(\x01\x12\x14\n\x0cmeanChunkDur\x18\n \x02(\x01\x12\x1c\n\x14meanHardwareMemLevel\x18\x0b \x02(\x02\x12\x1b\n\x13maxHardwareMemLevel\x18\x0c \x02(\x02\x12\x1b\n\x13minHardwareMemLevel\x18\r \x02(\x02\x12\x1c\n\x14lastHardwareMemLevel\x18\x0e \x02(\x02\x12\x19\n\x11meanStreamLoopDur\x18\x0f \x02(\x01\x12\x18\n\x10streamEfficiency\x18\x10 \x02(\x01\"\xd8\x02\n\x11LogsysPcacheReply\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x12\n\npersistDur\x18\x03 \x02(\x01\x12\x18\n\x10minNumDatablocks\x18\x04 \x02(\x05\x12\x11\n\tsizeBytes\x18\x05 \x02(\x03\x12 \n\x18totalDatablocksProcessed\x18\x06 \x02(\x04\x12\x16\n\x0enumTimeSamples\x18\x07 \x02(\x03\x12\x1f\n\x17\x61llTimeMeanDatablockDur\x18\x08 \x02(\x01\x12\x15\n\rnumDataBlocks\x18\t \x02(\x05\x12\x0e\n\x06tRange\x18\n \x03(\x01\x12\x0f\n\x07tsRange\x18\x0b \x03(\x03\x12\x12\n\nnumPriSigs\x18\x0c \x02(\x05\x12\x12\n\nnumAuxSigs\x18\r \x02(\x05\x12\x12\n\nnumDinSigs\x18\x0e \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x0f \x02(\x05\"5\n\x10TriggerModeState\x12!\n\x04mode\x18\x01 \x02(\x0e\x32\x13.allego.TriggerMode\"*\n\x12LoadAllMosiRequest\x12\x14\n\x0cregisterVals\x18\x01 \x03(\x05\"\x15\n\x13TransmitMosiRequest\"5\n\x0f\x44umpMisoRequest\x12\x10\n\x08nSamples\x18\x01 \x02(\x05\x12\x10\n\x08\x66ileName\x18\x02 \x02(\t\"\x80\x03\n\x15SinapsStatusRegisters\x12\x18\n\x10\x63\x61librationState\x18\x01 \x02(\x08\x12\x1b\n\x13\x63\x61librationProgress\x18\x02 \x02(\x01\x12\x1d\n\x15numActivePixelsShank0\x18\x03 \x02(\x05\x12\x1d\n\x15numActivePixelsShank1\x18\x04 \x02(\x05\x12\x1d\n\x15numActivePixelsShank2\x18\x05 \x02(\x05\x12\x1d\n\x15numActivePixelsShank3\x18\x06 \x02(\x05\x12\x0f\n\x07vRefFFA\x18\x07 \x02(\x01\x12\x0f\n\x07vRefFFB\x18\x08 \x02(\x01\x12\x0f\n\x07vRefFFC\x18\t \x02(\x01\x12\x0f\n\x07vRefFFD\x18\n \x02(\x01\x12\x10\n\x08isError0\x18\x0b \x02(\x08\x12\x10\n\x08isError1\x18\x0c \x02(\x08\x12\x10\n\x08isError2\x18\r \x02(\x08\x12\x10\n\x08isError3\x18\x0e \x02(\x08\x12\x13\n\x0bhostCounter\x18\x0f \x02(\x05\x12\x13\n\x0b\x66pgaCounter\x18\x10 \x02(\x05\"3\n\x0cHALdashboard\x12#\n\x04mode\x18\x01 \x02(\x0e\x32\x15.allego.AllegoHALmode\"\xbc\x06\n\nStimParams\x12$\n\tstimShape\x18\x01 \x02(\x0e\x32\x11.allego.StimShape\x12*\n\x0cstimPolarity\x18\x02 \x02(\x0e\x32\x14.allego.StimPolarity\x12\x1a\n\x12\x66irstPhaseDuration\x18\x03 \x02(\x01\x12\x1b\n\x13secondPhaseDuration\x18\x04 \x02(\x01\x12\x17\n\x0finterphaseDelay\x18\x05 \x02(\x01\x12\x1b\n\x13\x66irstPhaseAmplitude\x18\x06 \x02(\x01\x12\x1c\n\x14secondPhaseAmplitude\x18\x07 \x02(\x01\x12\x17\n\x0f\x62\x61selineVoltage\x18\x08 \x02(\x01\x12:\n\x12triggerEdgeOrLevel\x18\n \x02(\x0e\x32\x1e.allego.StimTriggerEdgeOrLevel\x12\x36\n\x10triggerHighOrLow\x18\x0b \x02(\x0e\x32\x1c.allego.StimTriggerHighOrLow\x12\x0f\n\x07\x65nabled\x18\x0c \x02(\x08\x12\x18\n\x10postTriggerDelay\x18\r \x02(\x01\x12.\n\x0cpulseOrTrain\x18\x0e \x02(\x0e\x32\x18.allego.StimPulseOrTrain\x12\x1a\n\x12numberOfStimPulses\x18\x0f \x02(\x05\x12\x18\n\x10pulseTrainPeriod\x18\x10 \x02(\x01\x12\x18\n\x10refractoryPeriod\x18\x11 \x02(\x01\x12\x18\n\x10preStimAmpSettle\x18\x12 \x02(\x01\x12\x19\n\x11postStimAmpSettle\x18\x13 \x02(\x01\x12\x19\n\x11maintainAmpSettle\x18\x14 \x02(\x08\x12\x17\n\x0f\x65nableAmpSettle\x18\x15 \x02(\x08\x12\x1d\n\x15postStimChargeRecovOn\x18\x16 \x02(\x01\x12\x1e\n\x16postStimChargeRecovOff\x18\x17 \x02(\x01\x12\x1c\n\x14\x65nableChargeRecovery\x18\x18 \x02(\x08\x12\x1f\n\x17triggerSourceIsKeypress\x18\x19 \x02(\x08\x12\x18\n\x10triggerSourceIdx\x18\x1a \x02(\x05\x12\x16\n\x0estimSysChanIdx\x18\x1b \x02(\x05\"\x89\x01\n\x0fStimParamsReply\x12\x33\n\x06params\x18\x01 \x03(\x0b\x32#.allego.StimParamsReply.ParamsEntry\x1a\x41\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.allego.StimParams:\x02\x38\x01\">\n\x18ManualStimTriggerRequest\x12\x0f\n\x07trigger\x18\x01 \x02(\x05\x12\x11\n\ttriggerOn\x18\x02 \x02(\x08*!\n\nStreamMode\x12\t\n\x05S_OFF\x10\x00\x12\x08\n\x04S_ON\x10\x01*!\n\nRecordMode\x12\t\n\x05R_OFF\x10\x00\x12\x08\n\x04R_ON\x10\x01*\x82\x04\n\x0c\x42\x61\x63kboneMode\x12\x10\n\x0cSMARTBOX_PRO\x10\x00\x12\x19\n\x15SMARTBOX_SIM_GEN_SINE\x10\x01\x12\x1b\n\x17SMARTBOX_SIM_GEN_SPIKES\x10\x02\x12\x1b\n\x17SMARTBOX_SIM_DATASOURCE\x10\x03\x12\x13\n\x0fOPEN_EPHYS_USB3\x10\x04\x12#\n\x1fINTAN_RECORDING_CONTROLLER_1024\x10\x05\x12\x14\n\x10SMARTBOX_CLASSIC\x10\x06\x12\"\n\x1eINTAN_RECORDING_CONTROLLER_512\x10\x07\x12\x13\n\x0fOPEN_EPHYS_USB2\x10\x08\x12\x0e\n\nINTAN_USB2\x10\t\x12 \n\x1cSMARTBOX_SIM_GEN_SINE_MAPPED\x10\n\x12#\n\x1fSMARTBOX_SIM_GEN_SINE_HIGH_FREQ\x10\x0b\x12$\n SMARTBOX_SIM_GEN_SINE_MULTI_BAND\x10\x0c\x12\x1b\n\x17SMARTBOX_PRO_SINAPS_256\x10\r\x12\x1c\n\x18SMARTBOX_PRO_SINAPS_1024\x10\x0e\x12\x10\n\x0cXDAQ_ONE_REC\x10\x0f\x12\x11\n\rXDAQ_ONE_STIM\x10\x10\x12\x11\n\rXDAQ_CORE_REC\x10\x11\x12\x12\n\x0eXDAQ_CORE_STIM\x10\x12*,\n\x07\x44IOMode\x12\n\n\x06manual\x10\x00\x12\n\n\x06\x65vents\x10\x01\x12\t\n\x05gated\x10\x02*O\n\x0bTriggerMode\x12\x0b\n\x07T_DIN_0\x10\x00\x12\x0b\n\x07T_DIN_1\x10\x01\x12\x0c\n\x08T_DOUT_0\x10\x02\x12\x0c\n\x08T_DOUT_1\x10\x03\x12\n\n\x06T_NONE\x10\x04*q\n\rAllegoHALmode\x12\x11\n\rA_HAL_GENERIC\x10\x00\x12\x13\n\x0f\x41_HAL_SPIKESORT\x10\x01\x12\x14\n\x10\x41_HAL_MULTISCALE\x10\x02\x12\"\n\x1e\x41_HAL_MULTISCALE_BIDIRECTIONAL\x10\x03*W\n\tStimShape\x12\x0c\n\x08\x42IPHASIC\x10\x00\x12\x1d\n\x19\x42IPHASIC_INTERPHASE_DELAY\x10\x01\x12\r\n\tTRIPHASIC\x10\x02\x12\x0e\n\nMONOPHASIC\x10\x03*4\n\x0cStimPolarity\x12\x12\n\x0e\x43\x41THODIC_FIRST\x10\x00\x12\x10\n\x0c\x41NODIC_FIRST\x10\x01*3\n\x16StimTriggerEdgeOrLevel\x12\x0b\n\x07ST_EDGE\x10\x00\x12\x0c\n\x08ST_LEVEL\x10\x01*/\n\x14StimTriggerHighOrLow\x12\x0b\n\x07ST_HIGH\x10\x00\x12\n\n\x06ST_LOW\x10\x01*5\n\x10StimPulseOrTrain\x12\x10\n\x0cSINGLE_PULSE\x10\x00\x12\x0f\n\x0bPULSE_TRAIN\x10\x01\x32\xe2%\n\nAllegoCore\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12:\n\x07Restart\x12\x16.allego.RestartRequest\x1a\x15.allego.StandardReply\"\x00\x12\x39\n\x05\x43lose\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x13GetRadixEnvironment\x12\x17.allego.StandardRequest\x1a\x18.allego.RadixEnvironment\"\x00\x12L\n\x10WorkspaceControl\x12\x1f.allego.WorkspaceControlRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x11GetRadiensServers\x12 .allego.GetRadiensServersRequest\x1a\x1b.allego.RadiensServersReply\"\x00\x12j\n\x1bGetStatusPollFieldsToUpdate\x12\'.allego.StatusPollFieldsToUpdateRequest\x1a .allego.StatusPollFieldsToUpdate\"\x00\x12\x46\n\rSetConfigCore\x12\x1c.allego.SetConfigCoreRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0fSetProfileState\x12\x19.allego.SetProfileRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\x12SetConfigRecording\x12\x17.allego.ConfigRecording\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0eSetStreamState\x12\x18.allego.SetStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0eSetRecordState\x12\x18.allego.SetRecordRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cSetDIOEvents\x12\x1c.allego.DIOModeEventsRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cSetDIOManual\x12\x1c.allego.DIOModeManualRequest\x1a\x15.allego.StandardReply\"\x00\x12?\n\x0bSetDIOGated\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nSetDACGain\x12\x16.allego.DACGainRequest\x1a\x15.allego.StandardReply\"\x00\x12\x41\n\x0cSetDACStream\x12\x18.allego.DACStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12;\n\tSetDACOff\x12\x15.allego.DACOffRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetSimPorts\x12\x1a.allego.SetSimPortsRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\rSetMuxChannel\x12\x1c.allego.SetMuxChannelRequest\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0eSetTriggerMode\x12\x18.allego.TriggerModeState\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\rSetPotVoltage\x12\x1c.allego.SetPotVoltageRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetPotRange\x12\x1a.allego.SetPotRangeRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\nSetPotMode\x12\x19.allego.SetPotModeRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x10SetPotCellEnable\x12\x1f.allego.SetPotCellEnableRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetDSPGroup\x12\x1a.allego.SetDSPGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12<\n\rSetStimParams\x12\x12.allego.StimParams\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\rGetStimParams\x12\x17.allego.StandardRequest\x1a\x17.allego.StimParamsReply\"\x00\x12N\n\x11ManualStimTrigger\x12 .allego.ManualStimTriggerRequest\x1a\x15.allego.StandardReply\"\x00\x12:\n\tGetConfig\x12\x17.allego.StandardRequest\x1a\x12.allego.ConfigCore\"\x00\x12H\n\x0cGetWorkspace\x12\x1b.allego.GetWorkspaceRequest\x1a\x19.allego.GetWorkspaceReply\"\x00\x12H\n\x12GetConfigRecording\x12\x17.allego.StandardRequest\x1a\x17.allego.ConfigRecording\"\x00\x12>\n\tGetStatus\x12\x17.allego.StandardRequest\x1a\x16.allego.BackboneStatus\"\x00\x12H\n\x12GetConfigAndStatus\x12\x17.allego.StandardRequest\x1a\x17.allego.ConfigAndStatus\"\x00\x12O\n\x13GetDataSourceParams\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceParams\"\x00\x12\x42\n\x11GetIntanImpedance\x12\x18.allego.ImpedanceRequest\x1a\x11.allego.Impedance\"\x00\x12?\n\x0bGetDSPGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x10.allego.DSPGroup\"\x00\x12\x42\n\tGetDIOReg\x12\x17.allego.StandardRequest\x1a\x1a.allego.DigitalOutRegister\"\x00\x12\x41\n\tGetDACReg\x12\x17.allego.StandardRequest\x1a\x19.allego.AnalogOutRegister\"\x00\x12<\n\tGetSerial\x12\x17.allego.StandardRequest\x1a\x14.allego.SerialNumber\"\x00\x12\x45\n\x0eGetTriggerMode\x12\x17.allego.StandardRequest\x1a\x18.allego.TriggerModeState\"\x00\x12\x42\n\x0bGetADCLevel\x12\x17.allego.StandardRequest\x1a\x18.allego.GetADCLevelReply\"\x00\x12\x45\n\x0bReadWireOut\x12\x1a.allego.ReadWireOutRequest\x1a\x18.allego.ReadWireOutReply\"\x00\x12O\n\x0fListSensorSpecs\x12\x1c.allego.SignalGroupIDRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12N\n\x11GetSignalGroupIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSignalGroupIDsReply\"\x00\x12N\n\x11GetSpikeSorterIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSpikeSorterIDsReply\"\x00\x12\x45\n\x0eGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12N\n\x11UpdateSignalGroup\x12 .allego.UpdateSignalGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12;\n\tScanPorts\x12\x17.allego.StandardRequest\x1a\x13.allego.SignalGroup\"\x00\x12>\n\tSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12O\n\x13GetDataSourceStatus\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceStatus\"\x00\x12H\n\x0c\x46\x65\x61tureStart\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12G\n\x0b\x46\x65\x61tureStop\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nGetPrivacy\x12\x17.allego.StandardRequest\x1a\x14.allego.PrivacyReply\"\x00\x12@\n\nSetPrivacy\x12\x19.allego.SetPrivacyRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bLoadAllMosi\x12\x1a.allego.LoadAllMosiRequest\x1a\x15.allego.StandardReply\"\x00\x12\x44\n\x0cTransmitMosi\x12\x1b.allego.TransmitMosiRequest\x1a\x15.allego.StandardReply\"\x00\x12<\n\x08\x44umpMiso\x12\x17.allego.DumpMisoRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x18GetSinapsStatusRegisters\x12\x17.allego.StandardRequest\x1a\x1d.allego.SinapsStatusRegisters\"\x00\x12L\n\x16GetOrCreateEventViewer\x12\x15.allego.EventViewerID\x1a\x19.allego.EventViewerConfig\"\x00\x12G\n\x11UpdateEventViewer\x12\x19.allego.EventViewerConfig\x1a\x15.allego.StandardReply\"\x00\x12T\n\x15ListEventViewerEvents\x12\x15.allego.EventViewerID\x1a\".allego.ListEventViewerEventsReply\"\x00\x12U\n\x13GetEventViewerEvent\x12\".allego.GetEventViewerEventRequest\x1a\x18.allego.EventViewerEvent\"\x00\x12L\n\x10ListEventViewers\x12\x17.allego.StandardRequest\x1a\x1d.allego.ListEventViewersReply\"\x00\x12\x42\n\x0fGetHALdashboard\x12\x17.allego.StandardRequest\x1a\x14.allego.HALdashboard\"\x00\x32\xe2\x02\n\x07Pcache1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\rGetHDSnapshot\x12\x19.allego.HDSnapshotRequest\x1a\x12.allego.HDSnapshot\"\x00\x12H\n\x15GetHDSnapshotFromHead\x12\x19.allego.HDSnapshotRequest\x1a\x12.allego.HDSnapshot\"\x00\x12=\n\nGetSignals\x12\x19.allego.GetSignalsRequest\x1a\x12.allego.RawSignals\"\x00\x12K\n\x12SetTimeRangeToHead\x12\x1c.allego.SignalGroupIDRequest\x1a\x15.allego.StandardReply\"\x00\x32\xd8\x01\n\x04Kpi1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12H\n\rKpiGetMetrics\x12\x15.allego.KpiMetricsReq\x1a\x1e.allego.KpiBundlePacketMetrics\"\x00\x12\x45\n\x0cGetKpiStatus\x12\x1b.allego.GetKpiStatusRequest\x1a\x16.allego.KpiStatusReply\"\x00\x32\xc2\t\n\x08Neurons1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12P\n\x12SpikeSorterCommand\x12!.allego.SpikeSorterCommandRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SpikeSorterSetParam\x12\".allego.SpikeSorterSetParamRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SpikeSorterSetParams\x12#.allego.SpikeSorterSetParamsRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n\x13SpikeSorterGetParam\x12\".allego.SpikeSorterStandardRequest\x1a\'.allego.GetSpikeSorterParamCommandReply\"\x00\x12U\n\x13SpikeSorterGetState\x12\".allego.SpikeSorterStandardRequest\x1a\x18.allego.SpikeSorterState\"\x00\x12\x65\n\x17SpikeSorterGetDashboard\x12\".allego.SpikeSorterStandardRequest\x1a$.allego.SpikeSorterGetDashboardReply\"\x00\x12i\n\x18SpikeSorterGetRasterData\x12\'.allego.SpikeSorterGetRasterDataRequest\x1a\".allego.SpikeSorterRasterDataReply\"\x00\x12m\n\x1a\x42iointerfaceGetSpikesDense\x12$.allego.BiointerfaceGetSpikesRequest\x1a\'.allego.BiointerfaceSpikeDataDenseReply\"\x00\x12\x66\n\x16\x42iointerfaceGetNeurons\x12%.allego.BiointerfaceGetNeuronsRequest\x1a#.allego.BiointerfaceGetNeuronsReply\"\x00\x12p\n\"BiointerfaceSeekEndSpikeTimestamps\x12\x31.allego.BiointerfaceSeekEndSpikeTimestampsRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\rSpikesGetSpec\x12\".allego.SpikeSorterStandardRequest\x1a\x17.allego.SpikesSpecReply\"\x00\x12Q\n\x0f\x42iointerfaceViz\x12\x1e.allego.BiointerfaceVizRequest\x1a\x1c.allego.BiointerfaceVizReply\"\x00\x42\x15Z\x13internal/radix/grpc'
  ,
  dependencies=[common__pb2.DESCRIPTOR,datasource__pb2.DESCRIPTOR,biointerface__pb2.DESCRIPTOR,spikesorter__pb2.DESCRIPTOR,])

_STREAMMODE = _descriptor.EnumDescriptor(
  name='StreamMode',
  full_name='allego.StreamMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='S_OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='S_ON', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6284,
  serialized_end=6317,
)
_sym_db.RegisterEnumDescriptor(_STREAMMODE)

StreamMode = enum_type_wrapper.EnumTypeWrapper(_STREAMMODE)
_RECORDMODE = _descriptor.EnumDescriptor(
  name='RecordMode',
  full_name='allego.RecordMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='R_OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='R_ON', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6319,
  serialized_end=6352,
)
_sym_db.RegisterEnumDescriptor(_RECORDMODE)

RecordMode = enum_type_wrapper.EnumTypeWrapper(_RECORDMODE)
_BACKBONEMODE = _descriptor.EnumDescriptor(
  name='BackboneMode',
  full_name='allego.BackboneMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_PRO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_GEN_SINE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_GEN_SPIKES', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_DATASOURCE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPEN_EPHYS_USB3', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTAN_RECORDING_CONTROLLER_1024', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_CLASSIC', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTAN_RECORDING_CONTROLLER_512', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPEN_EPHYS_USB2', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTAN_USB2', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_GEN_SINE_MAPPED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_GEN_SINE_HIGH_FREQ', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_SIM_GEN_SINE_MULTI_BAND', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_PRO_SINAPS_256', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMARTBOX_PRO_SINAPS_1024', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XDAQ_ONE_REC', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XDAQ_ONE_STIM', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XDAQ_CORE_REC', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XDAQ_CORE_STIM', index=18, number=18,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6355,
  serialized_end=6869,
)
_sym_db.RegisterEnumDescriptor(_BACKBONEMODE)

BackboneMode = enum_type_wrapper.EnumTypeWrapper(_BACKBONEMODE)
_DIOMODE = _descriptor.EnumDescriptor(
  name='DIOMode',
  full_name='allego.DIOMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='manual', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='events', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='gated', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6871,
  serialized_end=6915,
)
_sym_db.RegisterEnumDescriptor(_DIOMODE)

DIOMode = enum_type_wrapper.EnumTypeWrapper(_DIOMODE)
_TRIGGERMODE = _descriptor.EnumDescriptor(
  name='TriggerMode',
  full_name='allego.TriggerMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='T_DIN_0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T_DIN_1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T_DOUT_0', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T_DOUT_1', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='T_NONE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6917,
  serialized_end=6996,
)
_sym_db.RegisterEnumDescriptor(_TRIGGERMODE)

TriggerMode = enum_type_wrapper.EnumTypeWrapper(_TRIGGERMODE)
_ALLEGOHALMODE = _descriptor.EnumDescriptor(
  name='AllegoHALmode',
  full_name='allego.AllegoHALmode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='A_HAL_GENERIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A_HAL_SPIKESORT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A_HAL_MULTISCALE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='A_HAL_MULTISCALE_BIDIRECTIONAL', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6998,
  serialized_end=7111,
)
_sym_db.RegisterEnumDescriptor(_ALLEGOHALMODE)

AllegoHALmode = enum_type_wrapper.EnumTypeWrapper(_ALLEGOHALMODE)
_STIMSHAPE = _descriptor.EnumDescriptor(
  name='StimShape',
  full_name='allego.StimShape',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIPHASIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIPHASIC_INTERPHASE_DELAY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIPHASIC', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONOPHASIC', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7113,
  serialized_end=7200,
)
_sym_db.RegisterEnumDescriptor(_STIMSHAPE)

StimShape = enum_type_wrapper.EnumTypeWrapper(_STIMSHAPE)
_STIMPOLARITY = _descriptor.EnumDescriptor(
  name='StimPolarity',
  full_name='allego.StimPolarity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CATHODIC_FIRST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANODIC_FIRST', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7202,
  serialized_end=7254,
)
_sym_db.RegisterEnumDescriptor(_STIMPOLARITY)

StimPolarity = enum_type_wrapper.EnumTypeWrapper(_STIMPOLARITY)
_STIMTRIGGEREDGEORLEVEL = _descriptor.EnumDescriptor(
  name='StimTriggerEdgeOrLevel',
  full_name='allego.StimTriggerEdgeOrLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_EDGE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_LEVEL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7256,
  serialized_end=7307,
)
_sym_db.RegisterEnumDescriptor(_STIMTRIGGEREDGEORLEVEL)

StimTriggerEdgeOrLevel = enum_type_wrapper.EnumTypeWrapper(_STIMTRIGGEREDGEORLEVEL)
_STIMTRIGGERHIGHORLOW = _descriptor.EnumDescriptor(
  name='StimTriggerHighOrLow',
  full_name='allego.StimTriggerHighOrLow',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_HIGH', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_LOW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7309,
  serialized_end=7356,
)
_sym_db.RegisterEnumDescriptor(_STIMTRIGGERHIGHORLOW)

StimTriggerHighOrLow = enum_type_wrapper.EnumTypeWrapper(_STIMTRIGGERHIGHORLOW)
_STIMPULSEORTRAIN = _descriptor.EnumDescriptor(
  name='StimPulseOrTrain',
  full_name='allego.StimPulseOrTrain',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINGLE_PULSE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PULSE_TRAIN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7358,
  serialized_end=7411,
)
_sym_db.RegisterEnumDescriptor(_STIMPULSEORTRAIN)

StimPulseOrTrain = enum_type_wrapper.EnumTypeWrapper(_STIMPULSEORTRAIN)
S_OFF = 0
S_ON = 1
R_OFF = 0
R_ON = 1
SMARTBOX_PRO = 0
SMARTBOX_SIM_GEN_SINE = 1
SMARTBOX_SIM_GEN_SPIKES = 2
SMARTBOX_SIM_DATASOURCE = 3
OPEN_EPHYS_USB3 = 4
INTAN_RECORDING_CONTROLLER_1024 = 5
SMARTBOX_CLASSIC = 6
INTAN_RECORDING_CONTROLLER_512 = 7
OPEN_EPHYS_USB2 = 8
INTAN_USB2 = 9
SMARTBOX_SIM_GEN_SINE_MAPPED = 10
SMARTBOX_SIM_GEN_SINE_HIGH_FREQ = 11
SMARTBOX_SIM_GEN_SINE_MULTI_BAND = 12
SMARTBOX_PRO_SINAPS_256 = 13
SMARTBOX_PRO_SINAPS_1024 = 14
XDAQ_ONE_REC = 15
XDAQ_ONE_STIM = 16
XDAQ_CORE_REC = 17
XDAQ_CORE_STIM = 18
manual = 0
events = 1
gated = 2
T_DIN_0 = 0
T_DIN_1 = 1
T_DOUT_0 = 2
T_DOUT_1 = 3
T_NONE = 4
A_HAL_GENERIC = 0
A_HAL_SPIKESORT = 1
A_HAL_MULTISCALE = 2
A_HAL_MULTISCALE_BIDIRECTIONAL = 3
BIPHASIC = 0
BIPHASIC_INTERPHASE_DELAY = 1
TRIPHASIC = 2
MONOPHASIC = 3
CATHODIC_FIRST = 0
ANODIC_FIRST = 1
ST_EDGE = 0
ST_LEVEL = 1
ST_HIGH = 0
ST_LOW = 1
SINGLE_PULSE = 0
PULSE_TRAIN = 1


_LOGSYSTEMREQUEST_LOGSYSTEMMODE = _descriptor.EnumDescriptor(
  name='LogSystemMode',
  full_name='allego.LogSystemRequest.LogSystemMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='config', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='status', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='port_map', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pcache', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='sigstats', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='neurons_stats', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='base_signalgroup_map', index=6, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=377,
  serialized_end=501,
)
_sym_db.RegisterEnumDescriptor(_LOGSYSTEMREQUEST_LOGSYSTEMMODE)

_LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE = _descriptor.EnumDescriptor(
  name='LogSystemOutputMode',
  full_name='allego.LogSystemRequest.LogSystemOutputMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_OUT_STDERR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOG_OUT_CSV', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOG_OUT_MD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=503,
  serialized_end=577,
)
_sym_db.RegisterEnumDescriptor(_LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE)


_RESTARTREQUEST = _descriptor.Descriptor(
  name='RestartRequest',
  full_name='allego.RestartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.RestartRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=153,
)


_SETPROFILEREQUEST = _descriptor.Descriptor(
  name='SetProfileRequest',
  full_name='allego.SetProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='allego.SetProfileRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.SetProfileRequest.type', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dur', full_name='allego.SetProfileRequest.dur', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=213,
)


_LOGSYSTEMREQUEST = _descriptor.Descriptor(
  name='LogSystemRequest',
  full_name='allego.LogSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.LogSystemRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outMode', full_name='allego.LogSystemRequest.outMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outPathAndFile', full_name='allego.LogSystemRequest.outPathAndFile', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGSYSTEMREQUEST_LOGSYSTEMMODE,
    _LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=577,
)


_SETSTREAMREQUEST = _descriptor.Descriptor(
  name='SetStreamRequest',
  full_name='allego.SetStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SetStreamRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=631,
)


_SETRECORDREQUEST = _descriptor.Descriptor(
  name='SetRecordRequest',
  full_name='allego.SetRecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SetRecordRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=685,
)


_SETCONFIGCOREREQUEST = _descriptor.Descriptor(
  name='SetConfigCoreRequest',
  full_name='allego.SetConfigCoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SetConfigCoreRequest.sampFreq', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loopDur', full_name='allego.SetConfigCoreRequest.loopDur', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pcachePersistence', full_name='allego.SetConfigCoreRequest.pcachePersistence', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cableLength', full_name='allego.SetConfigCoreRequest.cableLength', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=813,
)


_CABLELENGTH = _descriptor.Descriptor(
  name='CableLength',
  full_name='allego.CableLength',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.CableLength.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cableLength', full_name='allego.CableLength.cableLength', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=877,
)


_CABLELENGTHS = _descriptor.Descriptor(
  name='CableLengths',
  full_name='allego.CableLengths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='A', full_name='allego.CableLengths.A', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='B', full_name='allego.CableLengths.B', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='C', full_name='allego.CableLengths.C', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='D', full_name='allego.CableLengths.D', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='E', full_name='allego.CableLengths.E', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='F', full_name='allego.CableLengths.F', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='G', full_name='allego.CableLengths.G', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='H', full_name='allego.CableLengths.H', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=981,
)


_CONFIGCORE = _descriptor.Descriptor(
  name='ConfigCore',
  full_name='allego.ConfigCore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allegoCoreServerPort', full_name='allego.ConfigCore.allegoCoreServerPort', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseSampFreq', full_name='allego.ConfigCore.baseSampFreq', index=1,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamLoopDurMs', full_name='allego.ConfigCore.streamLoopDurMs', index=2,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cableLengths', full_name='allego.ConfigCore.cableLengths', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backboneMode', full_name='allego.ConfigCore.backboneMode', index=4,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1161,
)


_RECORDINGSTATUS = _descriptor.Descriptor(
  name='RecordingStatus',
  full_name='allego.RecordingStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recordMode', full_name='allego.RecordingStatus.recordMode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activeFileName', full_name='allego.RecordingStatus.activeFileName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='allego.RecordingStatus.duration', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='allego.RecordingStatus.error', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1277,
)


_STREAMINGSTATUS = _descriptor.Descriptor(
  name='StreamingStatus',
  full_name='allego.StreamingStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamMode', full_name='allego.StreamingStatus.streamMode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primaryCacheTRange', full_name='allego.StreamingStatus.primaryCacheTRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hardwareMemoryLevel', full_name='allego.StreamingStatus.hardwareMemoryLevel', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1393,
)


_BACKBONESTATUS = _descriptor.Descriptor(
  name='BackboneStatus',
  full_name='allego.BackboneStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streaming', full_name='allego.BackboneStatus.streaming', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recording', full_name='allego.BackboneStatus.recording', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='allego.BackboneStatus.ports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isConnected', full_name='allego.BackboneStatus.isConnected', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpioChannelCount', full_name='allego.BackboneStatus.gpioChannelCount', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1396,
  serialized_end=1614,
)


_CONFIGANDSTATUS = _descriptor.Descriptor(
  name='ConfigAndStatus',
  full_name='allego.ConfigAndStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streaming', full_name='allego.ConfigAndStatus.streaming', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recording', full_name='allego.ConfigAndStatus.recording', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='allego.ConfigAndStatus.ports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isConnected', full_name='allego.ConfigAndStatus.isConnected', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpioChannelCount', full_name='allego.ConfigAndStatus.gpioChannelCount', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseSampFreq', full_name='allego.ConfigAndStatus.baseSampFreq', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cableLengths', full_name='allego.ConfigAndStatus.cableLengths', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backboneMode', full_name='allego.ConfigAndStatus.backboneMode', index=7,
      number=8, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1946,
)


_CONFIGRECORDING = _descriptor.Descriptor(
  name='ConfigRecording',
  full_name='allego.ConfigRecording',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='baseFileName', full_name='allego.ConfigRecording.baseFileName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseFilePath', full_name='allego.ConfigRecording.baseFilePath', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceIdx', full_name='allego.ConfigRecording.dataSourceIdx', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStamp', full_name='allego.ConfigRecording.timeStamp', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1948,
  serialized_end=2051,
)


_DIOMODEEVENTSREQUEST = _descriptor.Descriptor(
  name='DIOModeEventsRequest',
  full_name='allego.DIOModeEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chanIdx', full_name='allego.DIOModeEventsRequest.chanIdx', index=0,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThreshold', full_name='allego.DIOModeEventsRequest.eventThreshold', index=1,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventPolarity', full_name='allego.DIOModeEventsRequest.eventPolarity', index=2,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2139,
)


_DIOMODEMANUALREQUEST = _descriptor.Descriptor(
  name='DIOModeManualRequest',
  full_name='allego.DIOModeManualRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chanIdx', full_name='allego.DIOModeManualRequest.chanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='allego.DIOModeManualRequest.state', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2141,
  serialized_end=2195,
)


_DIGITALOUTCHANNELREGISTER = _descriptor.Descriptor(
  name='DigitalOutChannelRegister',
  full_name='allego.DigitalOutChannelRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='manualState', full_name='allego.DigitalOutChannelRegister.manualState', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThreshold', full_name='allego.DigitalOutChannelRegister.eventThreshold', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventPolarity', full_name='allego.DigitalOutChannelRegister.eventPolarity', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.DigitalOutChannelRegister.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2197,
  serialized_end=2312,
)


_DIGITALOUTREGISTER = _descriptor.Descriptor(
  name='DigitalOutRegister',
  full_name='allego.DigitalOutRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.DigitalOutRegister.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doutChanRegisters', full_name='allego.DigitalOutRegister.doutChanRegisters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2314,
  serialized_end=2427,
)


_DACGAINREQUEST = _descriptor.Descriptor(
  name='DACGainRequest',
  full_name='allego.DACGainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gain', full_name='allego.DACGainRequest.gain', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2429,
  serialized_end=2459,
)


_ANALOGOUTCHANNELREGISTER = _descriptor.Descriptor(
  name='AnalogOutChannelRegister',
  full_name='allego.AnalogOutChannelRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='PriNtvChanIdx', full_name='allego.AnalogOutChannelRegister.PriNtvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AnalogOutNtvChanIdx', full_name='allego.AnalogOutChannelRegister.AnalogOutNtvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Stream', full_name='allego.AnalogOutChannelRegister.Stream', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='StreamOffsetIdx', full_name='allego.AnalogOutChannelRegister.StreamOffsetIdx', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2461,
  serialized_end=2580,
)


_ANALOGOUTREGISTER = _descriptor.Descriptor(
  name='AnalogOutRegister',
  full_name='allego.AnalogOutRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='analogOutChannels', full_name='allego.AnalogOutRegister.analogOutChannels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gain', full_name='allego.AnalogOutRegister.gain', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2582,
  serialized_end=2676,
)


_SERIALNUMBER = _descriptor.Descriptor(
  name='SerialNumber',
  full_name='allego.SerialNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialNum', full_name='allego.SerialNumber.serialNum', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2678,
  serialized_end=2711,
)


_SETSIMPORTSREQUEST_SIMPORT = _descriptor.Descriptor(
  name='SimPort',
  full_name='allego.SetSimPortsRequest.SimPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SetSimPortsRequest.SimPort.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numChan', full_name='allego.SetSimPortsRequest.SimPort.numChan', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2789,
  serialized_end=2843,
)

_SETSIMPORTSREQUEST = _descriptor.Descriptor(
  name='SetSimPortsRequest',
  full_name='allego.SetSimPortsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='simPort', full_name='allego.SetSimPortsRequest.simPort', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SETSIMPORTSREQUEST_SIMPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2843,
)


_SETMUXCHANNELREQUEST = _descriptor.Descriptor(
  name='SetMuxChannelRequest',
  full_name='allego.SetMuxChannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='allego.SetMuxChannelRequest.channel', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2845,
  serialized_end=2884,
)


_SETPOTVOLTAGEREQUEST = _descriptor.Descriptor(
  name='SetPotVoltageRequest',
  full_name='allego.SetPotVoltageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voltage', full_name='allego.SetPotVoltageRequest.voltage', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2886,
  serialized_end=2925,
)


_GETADCLEVELREPLY = _descriptor.Descriptor(
  name='GetADCLevelReply',
  full_name='allego.GetADCLevelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='allego.GetADCLevelReply.level', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2927,
  serialized_end=2960,
)


_SETPOTRANGEREQUEST = _descriptor.Descriptor(
  name='SetPotRangeRequest',
  full_name='allego.SetPotRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='allego.SetPotRangeRequest.range', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2962,
  serialized_end=2997,
)


_SETPOTMODEREQUEST = _descriptor.Descriptor(
  name='SetPotModeRequest',
  full_name='allego.SetPotModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.SetPotModeRequest.mode', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2999,
  serialized_end=3032,
)


_SETPOTCELLENABLEREQUEST = _descriptor.Descriptor(
  name='SetPotCellEnableRequest',
  full_name='allego.SetPotCellEnableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='allego.SetPotCellEnableRequest.enable', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3034,
  serialized_end=3075,
)


_READWIREOUTREQUEST = _descriptor.Descriptor(
  name='ReadWireOutRequest',
  full_name='allego.ReadWireOutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wireOutAddress', full_name='allego.ReadWireOutRequest.wireOutAddress', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3077,
  serialized_end=3121,
)


_READWIREOUTREPLY = _descriptor.Descriptor(
  name='ReadWireOutReply',
  full_name='allego.ReadWireOutReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wireOutValue', full_name='allego.ReadWireOutReply.wireOutValue', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3123,
  serialized_end=3163,
)


_LOGSYSCONFIGREPLY = _descriptor.Descriptor(
  name='LogsysConfigReply',
  full_name='allego.LogsysConfigReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='systemMode', full_name='allego.LogsysConfigReply.systemMode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseSampFreq', full_name='allego.LogsysConfigReply.baseSampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamLoopDurMs', full_name='allego.LogsysConfigReply.streamLoopDurMs', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priCachePersistDur', full_name='allego.LogsysConfigReply.priCachePersistDur', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priCacheStatsUpdatePeriod', full_name='allego.LogsysConfigReply.priCacheStatsUpdatePeriod', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activeSigs', full_name='allego.LogsysConfigReply.activeSigs', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priChans', full_name='allego.LogsysConfigReply.priChans', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxChans', full_name='allego.LogsysConfigReply.auxChans', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dinChans', full_name='allego.LogsysConfigReply.dinChans', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doutChans', full_name='allego.LogsysConfigReply.doutChans', index=9,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portSpec', full_name='allego.LogsysConfigReply.portSpec', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numConnectedPorts', full_name='allego.LogsysConfigReply.numConnectedPorts', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3166,
  serialized_end=3493,
)


_PORTINFO = _descriptor.Descriptor(
  name='PortInfo',
  full_name='allego.PortInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.PortInfo.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.PortInfo.probe', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstage', full_name='allego.PortInfo.headstage', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSigs', full_name='allego.PortInfo.numSigs', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3495,
  serialized_end=3584,
)


_LOGSYSSTATUSREPLY = _descriptor.Descriptor(
  name='LogsysStatusReply',
  full_name='allego.LogsysStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recStat', full_name='allego.LogsysStatusReply.recStat', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sysStat', full_name='allego.LogsysStatusReply.sysStat', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3586,
  serialized_end=3685,
)


_RECORDERSTATUS = _descriptor.Descriptor(
  name='RecorderStatus',
  full_name='allego.RecorderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recordMode', full_name='allego.RecorderStatus.recordMode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='allego.RecorderStatus.duration', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beta', full_name='allego.RecorderStatus.beta', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='allego.RecorderStatus.sizeBytes', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.RecorderStatus.path', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.RecorderStatus.baseName', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceIdx', full_name='allego.RecorderStatus.dataSourceIdx', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activeFileName', full_name='allego.RecorderStatus.activeFileName', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3688,
  serialized_end=3874,
)


_SYSTEMSTATUS = _descriptor.Descriptor(
  name='SystemStatus',
  full_name='allego.SystemStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamMode', full_name='allego.SystemStatus.streamMode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseSampFreq', full_name='allego.SystemStatus.baseSampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPriSigs', full_name='allego.SystemStatus.numPriSigs', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numAuxSigs', full_name='allego.SystemStatus.numAuxSigs', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDinSigs', full_name='allego.SystemStatus.numDinSigs', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDoutSigs', full_name='allego.SystemStatus.numDoutSigs', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tStampRange', full_name='allego.SystemStatus.tStampRange', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tRange', full_name='allego.SystemStatus.tRange', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamDur', full_name='allego.SystemStatus.streamDur', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanChunkDur', full_name='allego.SystemStatus.meanChunkDur', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanHardwareMemLevel', full_name='allego.SystemStatus.meanHardwareMemLevel', index=10,
      number=11, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxHardwareMemLevel', full_name='allego.SystemStatus.maxHardwareMemLevel', index=11,
      number=12, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minHardwareMemLevel', full_name='allego.SystemStatus.minHardwareMemLevel', index=12,
      number=13, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastHardwareMemLevel', full_name='allego.SystemStatus.lastHardwareMemLevel', index=13,
      number=14, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanStreamLoopDur', full_name='allego.SystemStatus.meanStreamLoopDur', index=14,
      number=15, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamEfficiency', full_name='allego.SystemStatus.streamEfficiency', index=15,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3877,
  serialized_end=4283,
)


_LOGSYSPCACHEREPLY = _descriptor.Descriptor(
  name='LogsysPcacheReply',
  full_name='allego.LogsysPcacheReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.LogsysPcacheReply.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.LogsysPcacheReply.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistDur', full_name='allego.LogsysPcacheReply.persistDur', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minNumDatablocks', full_name='allego.LogsysPcacheReply.minNumDatablocks', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='allego.LogsysPcacheReply.sizeBytes', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalDatablocksProcessed', full_name='allego.LogsysPcacheReply.totalDatablocksProcessed', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numTimeSamples', full_name='allego.LogsysPcacheReply.numTimeSamples', index=6,
      number=7, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allTimeMeanDatablockDur', full_name='allego.LogsysPcacheReply.allTimeMeanDatablockDur', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDataBlocks', full_name='allego.LogsysPcacheReply.numDataBlocks', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tRange', full_name='allego.LogsysPcacheReply.tRange', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsRange', full_name='allego.LogsysPcacheReply.tsRange', index=10,
      number=11, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPriSigs', full_name='allego.LogsysPcacheReply.numPriSigs', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numAuxSigs', full_name='allego.LogsysPcacheReply.numAuxSigs', index=12,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDinSigs', full_name='allego.LogsysPcacheReply.numDinSigs', index=13,
      number=14, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDoutSigs', full_name='allego.LogsysPcacheReply.numDoutSigs', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4286,
  serialized_end=4630,
)


_TRIGGERMODESTATE = _descriptor.Descriptor(
  name='TriggerModeState',
  full_name='allego.TriggerModeState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.TriggerModeState.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4632,
  serialized_end=4685,
)


_LOADALLMOSIREQUEST = _descriptor.Descriptor(
  name='LoadAllMosiRequest',
  full_name='allego.LoadAllMosiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registerVals', full_name='allego.LoadAllMosiRequest.registerVals', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4687,
  serialized_end=4729,
)


_TRANSMITMOSIREQUEST = _descriptor.Descriptor(
  name='TransmitMosiRequest',
  full_name='allego.TransmitMosiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4731,
  serialized_end=4752,
)


_DUMPMISOREQUEST = _descriptor.Descriptor(
  name='DumpMisoRequest',
  full_name='allego.DumpMisoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nSamples', full_name='allego.DumpMisoRequest.nSamples', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='allego.DumpMisoRequest.fileName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4754,
  serialized_end=4807,
)


_SINAPSSTATUSREGISTERS = _descriptor.Descriptor(
  name='SinapsStatusRegisters',
  full_name='allego.SinapsStatusRegisters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calibrationState', full_name='allego.SinapsStatusRegisters.calibrationState', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrationProgress', full_name='allego.SinapsStatusRegisters.calibrationProgress', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numActivePixelsShank0', full_name='allego.SinapsStatusRegisters.numActivePixelsShank0', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numActivePixelsShank1', full_name='allego.SinapsStatusRegisters.numActivePixelsShank1', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numActivePixelsShank2', full_name='allego.SinapsStatusRegisters.numActivePixelsShank2', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numActivePixelsShank3', full_name='allego.SinapsStatusRegisters.numActivePixelsShank3', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vRefFFA', full_name='allego.SinapsStatusRegisters.vRefFFA', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vRefFFB', full_name='allego.SinapsStatusRegisters.vRefFFB', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vRefFFC', full_name='allego.SinapsStatusRegisters.vRefFFC', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vRefFFD', full_name='allego.SinapsStatusRegisters.vRefFFD', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isError0', full_name='allego.SinapsStatusRegisters.isError0', index=10,
      number=11, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isError1', full_name='allego.SinapsStatusRegisters.isError1', index=11,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isError2', full_name='allego.SinapsStatusRegisters.isError2', index=12,
      number=13, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isError3', full_name='allego.SinapsStatusRegisters.isError3', index=13,
      number=14, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostCounter', full_name='allego.SinapsStatusRegisters.hostCounter', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpgaCounter', full_name='allego.SinapsStatusRegisters.fpgaCounter', index=15,
      number=16, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4810,
  serialized_end=5194,
)


_HALDASHBOARD = _descriptor.Descriptor(
  name='HALdashboard',
  full_name='allego.HALdashboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.HALdashboard.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5196,
  serialized_end=5247,
)


_STIMPARAMS = _descriptor.Descriptor(
  name='StimParams',
  full_name='allego.StimParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stimShape', full_name='allego.StimParams.stimShape', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stimPolarity', full_name='allego.StimParams.stimPolarity', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firstPhaseDuration', full_name='allego.StimParams.firstPhaseDuration', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondPhaseDuration', full_name='allego.StimParams.secondPhaseDuration', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interphaseDelay', full_name='allego.StimParams.interphaseDelay', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firstPhaseAmplitude', full_name='allego.StimParams.firstPhaseAmplitude', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondPhaseAmplitude', full_name='allego.StimParams.secondPhaseAmplitude', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baselineVoltage', full_name='allego.StimParams.baselineVoltage', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerEdgeOrLevel', full_name='allego.StimParams.triggerEdgeOrLevel', index=8,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerHighOrLow', full_name='allego.StimParams.triggerHighOrLow', index=9,
      number=11, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='allego.StimParams.enabled', index=10,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postTriggerDelay', full_name='allego.StimParams.postTriggerDelay', index=11,
      number=13, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pulseOrTrain', full_name='allego.StimParams.pulseOrTrain', index=12,
      number=14, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfStimPulses', full_name='allego.StimParams.numberOfStimPulses', index=13,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pulseTrainPeriod', full_name='allego.StimParams.pulseTrainPeriod', index=14,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refractoryPeriod', full_name='allego.StimParams.refractoryPeriod', index=15,
      number=17, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preStimAmpSettle', full_name='allego.StimParams.preStimAmpSettle', index=16,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStimAmpSettle', full_name='allego.StimParams.postStimAmpSettle', index=17,
      number=19, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maintainAmpSettle', full_name='allego.StimParams.maintainAmpSettle', index=18,
      number=20, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enableAmpSettle', full_name='allego.StimParams.enableAmpSettle', index=19,
      number=21, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStimChargeRecovOn', full_name='allego.StimParams.postStimChargeRecovOn', index=20,
      number=22, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStimChargeRecovOff', full_name='allego.StimParams.postStimChargeRecovOff', index=21,
      number=23, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enableChargeRecovery', full_name='allego.StimParams.enableChargeRecovery', index=22,
      number=24, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerSourceIsKeypress', full_name='allego.StimParams.triggerSourceIsKeypress', index=23,
      number=25, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerSourceIdx', full_name='allego.StimParams.triggerSourceIdx', index=24,
      number=26, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stimSysChanIdx', full_name='allego.StimParams.stimSysChanIdx', index=25,
      number=27, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5250,
  serialized_end=6078,
)


_STIMPARAMSREPLY_PARAMSENTRY = _descriptor.Descriptor(
  name='ParamsEntry',
  full_name='allego.StimParamsReply.ParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.StimParamsReply.ParamsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.StimParamsReply.ParamsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6153,
  serialized_end=6218,
)

_STIMPARAMSREPLY = _descriptor.Descriptor(
  name='StimParamsReply',
  full_name='allego.StimParamsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='allego.StimParamsReply.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STIMPARAMSREPLY_PARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6081,
  serialized_end=6218,
)


_MANUALSTIMTRIGGERREQUEST = _descriptor.Descriptor(
  name='ManualStimTriggerRequest',
  full_name='allego.ManualStimTriggerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger', full_name='allego.ManualStimTriggerRequest.trigger', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerOn', full_name='allego.ManualStimTriggerRequest.triggerOn', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6220,
  serialized_end=6282,
)

_RESTARTREQUEST.fields_by_name['mode'].enum_type = _BACKBONEMODE
_LOGSYSTEMREQUEST.fields_by_name['mode'].enum_type = _LOGSYSTEMREQUEST_LOGSYSTEMMODE
_LOGSYSTEMREQUEST.fields_by_name['outMode'].enum_type = _LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE
_LOGSYSTEMREQUEST_LOGSYSTEMMODE.containing_type = _LOGSYSTEMREQUEST
_LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE.containing_type = _LOGSYSTEMREQUEST
_SETSTREAMREQUEST.fields_by_name['mode'].enum_type = _STREAMMODE
_SETRECORDREQUEST.fields_by_name['mode'].enum_type = _RECORDMODE
_SETCONFIGCOREREQUEST.fields_by_name['cableLength'].message_type = _CABLELENGTH
_CABLELENGTH.fields_by_name['port'].enum_type = common__pb2._PORT
_CONFIGCORE.fields_by_name['cableLengths'].message_type = _CABLELENGTHS
_CONFIGCORE.fields_by_name['backboneMode'].enum_type = _BACKBONEMODE
_RECORDINGSTATUS.fields_by_name['recordMode'].enum_type = _RECORDMODE
_STREAMINGSTATUS.fields_by_name['streamMode'].enum_type = _STREAMMODE
_BACKBONESTATUS.fields_by_name['streaming'].message_type = _STREAMINGSTATUS
_BACKBONESTATUS.fields_by_name['recording'].message_type = _RECORDINGSTATUS
_BACKBONESTATUS.fields_by_name['ports'].message_type = common__pb2._PORTCHANNELCOUNT
_BACKBONESTATUS.fields_by_name['gpioChannelCount'].message_type = common__pb2._GPIOCHANNELCOUNT
_CONFIGANDSTATUS.fields_by_name['streaming'].message_type = _STREAMINGSTATUS
_CONFIGANDSTATUS.fields_by_name['recording'].message_type = _RECORDINGSTATUS
_CONFIGANDSTATUS.fields_by_name['ports'].message_type = common__pb2._PORTCHANNELCOUNT
_CONFIGANDSTATUS.fields_by_name['gpioChannelCount'].message_type = common__pb2._GPIOCHANNELCOUNT
_CONFIGANDSTATUS.fields_by_name['cableLengths'].message_type = _CABLELENGTHS
_CONFIGANDSTATUS.fields_by_name['backboneMode'].enum_type = _BACKBONEMODE
_DIGITALOUTREGISTER.fields_by_name['mode'].enum_type = _DIOMODE
_DIGITALOUTREGISTER.fields_by_name['doutChanRegisters'].message_type = _DIGITALOUTCHANNELREGISTER
_ANALOGOUTREGISTER.fields_by_name['analogOutChannels'].message_type = _ANALOGOUTCHANNELREGISTER
_SETSIMPORTSREQUEST_SIMPORT.fields_by_name['port'].enum_type = common__pb2._PORT
_SETSIMPORTSREQUEST_SIMPORT.containing_type = _SETSIMPORTSREQUEST
_SETSIMPORTSREQUEST.fields_by_name['simPort'].message_type = _SETSIMPORTSREQUEST_SIMPORT
_LOGSYSCONFIGREPLY.fields_by_name['systemMode'].enum_type = _BACKBONEMODE
_LOGSYSCONFIGREPLY.fields_by_name['portSpec'].message_type = _PORTINFO
_PORTINFO.fields_by_name['port'].enum_type = common__pb2._PORT
_LOGSYSSTATUSREPLY.fields_by_name['recStat'].message_type = _RECORDERSTATUS
_LOGSYSSTATUSREPLY.fields_by_name['sysStat'].message_type = _SYSTEMSTATUS
_RECORDERSTATUS.fields_by_name['recordMode'].enum_type = _RECORDMODE
_SYSTEMSTATUS.fields_by_name['streamMode'].enum_type = _STREAMMODE
_TRIGGERMODESTATE.fields_by_name['mode'].enum_type = _TRIGGERMODE
_HALDASHBOARD.fields_by_name['mode'].enum_type = _ALLEGOHALMODE
_STIMPARAMS.fields_by_name['stimShape'].enum_type = _STIMSHAPE
_STIMPARAMS.fields_by_name['stimPolarity'].enum_type = _STIMPOLARITY
_STIMPARAMS.fields_by_name['triggerEdgeOrLevel'].enum_type = _STIMTRIGGEREDGEORLEVEL
_STIMPARAMS.fields_by_name['triggerHighOrLow'].enum_type = _STIMTRIGGERHIGHORLOW
_STIMPARAMS.fields_by_name['pulseOrTrain'].enum_type = _STIMPULSEORTRAIN
_STIMPARAMSREPLY_PARAMSENTRY.fields_by_name['value'].message_type = _STIMPARAMS
_STIMPARAMSREPLY_PARAMSENTRY.containing_type = _STIMPARAMSREPLY
_STIMPARAMSREPLY.fields_by_name['params'].message_type = _STIMPARAMSREPLY_PARAMSENTRY
DESCRIPTOR.message_types_by_name['RestartRequest'] = _RESTARTREQUEST
DESCRIPTOR.message_types_by_name['SetProfileRequest'] = _SETPROFILEREQUEST
DESCRIPTOR.message_types_by_name['LogSystemRequest'] = _LOGSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['SetStreamRequest'] = _SETSTREAMREQUEST
DESCRIPTOR.message_types_by_name['SetRecordRequest'] = _SETRECORDREQUEST
DESCRIPTOR.message_types_by_name['SetConfigCoreRequest'] = _SETCONFIGCOREREQUEST
DESCRIPTOR.message_types_by_name['CableLength'] = _CABLELENGTH
DESCRIPTOR.message_types_by_name['CableLengths'] = _CABLELENGTHS
DESCRIPTOR.message_types_by_name['ConfigCore'] = _CONFIGCORE
DESCRIPTOR.message_types_by_name['RecordingStatus'] = _RECORDINGSTATUS
DESCRIPTOR.message_types_by_name['StreamingStatus'] = _STREAMINGSTATUS
DESCRIPTOR.message_types_by_name['BackboneStatus'] = _BACKBONESTATUS
DESCRIPTOR.message_types_by_name['ConfigAndStatus'] = _CONFIGANDSTATUS
DESCRIPTOR.message_types_by_name['ConfigRecording'] = _CONFIGRECORDING
DESCRIPTOR.message_types_by_name['DIOModeEventsRequest'] = _DIOMODEEVENTSREQUEST
DESCRIPTOR.message_types_by_name['DIOModeManualRequest'] = _DIOMODEMANUALREQUEST
DESCRIPTOR.message_types_by_name['DigitalOutChannelRegister'] = _DIGITALOUTCHANNELREGISTER
DESCRIPTOR.message_types_by_name['DigitalOutRegister'] = _DIGITALOUTREGISTER
DESCRIPTOR.message_types_by_name['DACGainRequest'] = _DACGAINREQUEST
DESCRIPTOR.message_types_by_name['AnalogOutChannelRegister'] = _ANALOGOUTCHANNELREGISTER
DESCRIPTOR.message_types_by_name['AnalogOutRegister'] = _ANALOGOUTREGISTER
DESCRIPTOR.message_types_by_name['SerialNumber'] = _SERIALNUMBER
DESCRIPTOR.message_types_by_name['SetSimPortsRequest'] = _SETSIMPORTSREQUEST
DESCRIPTOR.message_types_by_name['SetMuxChannelRequest'] = _SETMUXCHANNELREQUEST
DESCRIPTOR.message_types_by_name['SetPotVoltageRequest'] = _SETPOTVOLTAGEREQUEST
DESCRIPTOR.message_types_by_name['GetADCLevelReply'] = _GETADCLEVELREPLY
DESCRIPTOR.message_types_by_name['SetPotRangeRequest'] = _SETPOTRANGEREQUEST
DESCRIPTOR.message_types_by_name['SetPotModeRequest'] = _SETPOTMODEREQUEST
DESCRIPTOR.message_types_by_name['SetPotCellEnableRequest'] = _SETPOTCELLENABLEREQUEST
DESCRIPTOR.message_types_by_name['ReadWireOutRequest'] = _READWIREOUTREQUEST
DESCRIPTOR.message_types_by_name['ReadWireOutReply'] = _READWIREOUTREPLY
DESCRIPTOR.message_types_by_name['LogsysConfigReply'] = _LOGSYSCONFIGREPLY
DESCRIPTOR.message_types_by_name['PortInfo'] = _PORTINFO
DESCRIPTOR.message_types_by_name['LogsysStatusReply'] = _LOGSYSSTATUSREPLY
DESCRIPTOR.message_types_by_name['RecorderStatus'] = _RECORDERSTATUS
DESCRIPTOR.message_types_by_name['SystemStatus'] = _SYSTEMSTATUS
DESCRIPTOR.message_types_by_name['LogsysPcacheReply'] = _LOGSYSPCACHEREPLY
DESCRIPTOR.message_types_by_name['TriggerModeState'] = _TRIGGERMODESTATE
DESCRIPTOR.message_types_by_name['LoadAllMosiRequest'] = _LOADALLMOSIREQUEST
DESCRIPTOR.message_types_by_name['TransmitMosiRequest'] = _TRANSMITMOSIREQUEST
DESCRIPTOR.message_types_by_name['DumpMisoRequest'] = _DUMPMISOREQUEST
DESCRIPTOR.message_types_by_name['SinapsStatusRegisters'] = _SINAPSSTATUSREGISTERS
DESCRIPTOR.message_types_by_name['HALdashboard'] = _HALDASHBOARD
DESCRIPTOR.message_types_by_name['StimParams'] = _STIMPARAMS
DESCRIPTOR.message_types_by_name['StimParamsReply'] = _STIMPARAMSREPLY
DESCRIPTOR.message_types_by_name['ManualStimTriggerRequest'] = _MANUALSTIMTRIGGERREQUEST
DESCRIPTOR.enum_types_by_name['StreamMode'] = _STREAMMODE
DESCRIPTOR.enum_types_by_name['RecordMode'] = _RECORDMODE
DESCRIPTOR.enum_types_by_name['BackboneMode'] = _BACKBONEMODE
DESCRIPTOR.enum_types_by_name['DIOMode'] = _DIOMODE
DESCRIPTOR.enum_types_by_name['TriggerMode'] = _TRIGGERMODE
DESCRIPTOR.enum_types_by_name['AllegoHALmode'] = _ALLEGOHALMODE
DESCRIPTOR.enum_types_by_name['StimShape'] = _STIMSHAPE
DESCRIPTOR.enum_types_by_name['StimPolarity'] = _STIMPOLARITY
DESCRIPTOR.enum_types_by_name['StimTriggerEdgeOrLevel'] = _STIMTRIGGEREDGEORLEVEL
DESCRIPTOR.enum_types_by_name['StimTriggerHighOrLow'] = _STIMTRIGGERHIGHORLOW
DESCRIPTOR.enum_types_by_name['StimPulseOrTrain'] = _STIMPULSEORTRAIN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RestartRequest = _reflection.GeneratedProtocolMessageType('RestartRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RestartRequest)
  })
_sym_db.RegisterMessage(RestartRequest)

SetProfileRequest = _reflection.GeneratedProtocolMessageType('SetProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPROFILEREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetProfileRequest)
  })
_sym_db.RegisterMessage(SetProfileRequest)

LogSystemRequest = _reflection.GeneratedProtocolMessageType('LogSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSTEMREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogSystemRequest)
  })
_sym_db.RegisterMessage(LogSystemRequest)

SetStreamRequest = _reflection.GeneratedProtocolMessageType('SetStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSTREAMREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetStreamRequest)
  })
_sym_db.RegisterMessage(SetStreamRequest)

SetRecordRequest = _reflection.GeneratedProtocolMessageType('SetRecordRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETRECORDREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetRecordRequest)
  })
_sym_db.RegisterMessage(SetRecordRequest)

SetConfigCoreRequest = _reflection.GeneratedProtocolMessageType('SetConfigCoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGCOREREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetConfigCoreRequest)
  })
_sym_db.RegisterMessage(SetConfigCoreRequest)

CableLength = _reflection.GeneratedProtocolMessageType('CableLength', (_message.Message,), {
  'DESCRIPTOR' : _CABLELENGTH,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.CableLength)
  })
_sym_db.RegisterMessage(CableLength)

CableLengths = _reflection.GeneratedProtocolMessageType('CableLengths', (_message.Message,), {
  'DESCRIPTOR' : _CABLELENGTHS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.CableLengths)
  })
_sym_db.RegisterMessage(CableLengths)

ConfigCore = _reflection.GeneratedProtocolMessageType('ConfigCore', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGCORE,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ConfigCore)
  })
_sym_db.RegisterMessage(ConfigCore)

RecordingStatus = _reflection.GeneratedProtocolMessageType('RecordingStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECORDINGSTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RecordingStatus)
  })
_sym_db.RegisterMessage(RecordingStatus)

StreamingStatus = _reflection.GeneratedProtocolMessageType('StreamingStatus', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGSTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.StreamingStatus)
  })
_sym_db.RegisterMessage(StreamingStatus)

BackboneStatus = _reflection.GeneratedProtocolMessageType('BackboneStatus', (_message.Message,), {
  'DESCRIPTOR' : _BACKBONESTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.BackboneStatus)
  })
_sym_db.RegisterMessage(BackboneStatus)

ConfigAndStatus = _reflection.GeneratedProtocolMessageType('ConfigAndStatus', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGANDSTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ConfigAndStatus)
  })
_sym_db.RegisterMessage(ConfigAndStatus)

ConfigRecording = _reflection.GeneratedProtocolMessageType('ConfigRecording', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGRECORDING,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ConfigRecording)
  })
_sym_db.RegisterMessage(ConfigRecording)

DIOModeEventsRequest = _reflection.GeneratedProtocolMessageType('DIOModeEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIOMODEEVENTSREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DIOModeEventsRequest)
  })
_sym_db.RegisterMessage(DIOModeEventsRequest)

DIOModeManualRequest = _reflection.GeneratedProtocolMessageType('DIOModeManualRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIOMODEMANUALREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DIOModeManualRequest)
  })
_sym_db.RegisterMessage(DIOModeManualRequest)

DigitalOutChannelRegister = _reflection.GeneratedProtocolMessageType('DigitalOutChannelRegister', (_message.Message,), {
  'DESCRIPTOR' : _DIGITALOUTCHANNELREGISTER,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DigitalOutChannelRegister)
  })
_sym_db.RegisterMessage(DigitalOutChannelRegister)

DigitalOutRegister = _reflection.GeneratedProtocolMessageType('DigitalOutRegister', (_message.Message,), {
  'DESCRIPTOR' : _DIGITALOUTREGISTER,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DigitalOutRegister)
  })
_sym_db.RegisterMessage(DigitalOutRegister)

DACGainRequest = _reflection.GeneratedProtocolMessageType('DACGainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DACGAINREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DACGainRequest)
  })
_sym_db.RegisterMessage(DACGainRequest)

AnalogOutChannelRegister = _reflection.GeneratedProtocolMessageType('AnalogOutChannelRegister', (_message.Message,), {
  'DESCRIPTOR' : _ANALOGOUTCHANNELREGISTER,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.AnalogOutChannelRegister)
  })
_sym_db.RegisterMessage(AnalogOutChannelRegister)

AnalogOutRegister = _reflection.GeneratedProtocolMessageType('AnalogOutRegister', (_message.Message,), {
  'DESCRIPTOR' : _ANALOGOUTREGISTER,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.AnalogOutRegister)
  })
_sym_db.RegisterMessage(AnalogOutRegister)

SerialNumber = _reflection.GeneratedProtocolMessageType('SerialNumber', (_message.Message,), {
  'DESCRIPTOR' : _SERIALNUMBER,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SerialNumber)
  })
_sym_db.RegisterMessage(SerialNumber)

SetSimPortsRequest = _reflection.GeneratedProtocolMessageType('SetSimPortsRequest', (_message.Message,), {

  'SimPort' : _reflection.GeneratedProtocolMessageType('SimPort', (_message.Message,), {
    'DESCRIPTOR' : _SETSIMPORTSREQUEST_SIMPORT,
    '__module__' : 'allegoserver_pb2'
    # @@protoc_insertion_point(class_scope:allego.SetSimPortsRequest.SimPort)
    })
  ,
  'DESCRIPTOR' : _SETSIMPORTSREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetSimPortsRequest)
  })
_sym_db.RegisterMessage(SetSimPortsRequest)
_sym_db.RegisterMessage(SetSimPortsRequest.SimPort)

SetMuxChannelRequest = _reflection.GeneratedProtocolMessageType('SetMuxChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMUXCHANNELREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetMuxChannelRequest)
  })
_sym_db.RegisterMessage(SetMuxChannelRequest)

SetPotVoltageRequest = _reflection.GeneratedProtocolMessageType('SetPotVoltageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOTVOLTAGEREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPotVoltageRequest)
  })
_sym_db.RegisterMessage(SetPotVoltageRequest)

GetADCLevelReply = _reflection.GeneratedProtocolMessageType('GetADCLevelReply', (_message.Message,), {
  'DESCRIPTOR' : _GETADCLEVELREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetADCLevelReply)
  })
_sym_db.RegisterMessage(GetADCLevelReply)

SetPotRangeRequest = _reflection.GeneratedProtocolMessageType('SetPotRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOTRANGEREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPotRangeRequest)
  })
_sym_db.RegisterMessage(SetPotRangeRequest)

SetPotModeRequest = _reflection.GeneratedProtocolMessageType('SetPotModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOTMODEREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPotModeRequest)
  })
_sym_db.RegisterMessage(SetPotModeRequest)

SetPotCellEnableRequest = _reflection.GeneratedProtocolMessageType('SetPotCellEnableRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOTCELLENABLEREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPotCellEnableRequest)
  })
_sym_db.RegisterMessage(SetPotCellEnableRequest)

ReadWireOutRequest = _reflection.GeneratedProtocolMessageType('ReadWireOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _READWIREOUTREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ReadWireOutRequest)
  })
_sym_db.RegisterMessage(ReadWireOutRequest)

ReadWireOutReply = _reflection.GeneratedProtocolMessageType('ReadWireOutReply', (_message.Message,), {
  'DESCRIPTOR' : _READWIREOUTREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ReadWireOutReply)
  })
_sym_db.RegisterMessage(ReadWireOutReply)

LogsysConfigReply = _reflection.GeneratedProtocolMessageType('LogsysConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSCONFIGREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogsysConfigReply)
  })
_sym_db.RegisterMessage(LogsysConfigReply)

PortInfo = _reflection.GeneratedProtocolMessageType('PortInfo', (_message.Message,), {
  'DESCRIPTOR' : _PORTINFO,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.PortInfo)
  })
_sym_db.RegisterMessage(PortInfo)

LogsysStatusReply = _reflection.GeneratedProtocolMessageType('LogsysStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSSTATUSREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogsysStatusReply)
  })
_sym_db.RegisterMessage(LogsysStatusReply)

RecorderStatus = _reflection.GeneratedProtocolMessageType('RecorderStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECORDERSTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RecorderStatus)
  })
_sym_db.RegisterMessage(RecorderStatus)

SystemStatus = _reflection.GeneratedProtocolMessageType('SystemStatus', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSTATUS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SystemStatus)
  })
_sym_db.RegisterMessage(SystemStatus)

LogsysPcacheReply = _reflection.GeneratedProtocolMessageType('LogsysPcacheReply', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSPCACHEREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogsysPcacheReply)
  })
_sym_db.RegisterMessage(LogsysPcacheReply)

TriggerModeState = _reflection.GeneratedProtocolMessageType('TriggerModeState', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERMODESTATE,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.TriggerModeState)
  })
_sym_db.RegisterMessage(TriggerModeState)

LoadAllMosiRequest = _reflection.GeneratedProtocolMessageType('LoadAllMosiRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADALLMOSIREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.LoadAllMosiRequest)
  })
_sym_db.RegisterMessage(LoadAllMosiRequest)

TransmitMosiRequest = _reflection.GeneratedProtocolMessageType('TransmitMosiRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMITMOSIREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.TransmitMosiRequest)
  })
_sym_db.RegisterMessage(TransmitMosiRequest)

DumpMisoRequest = _reflection.GeneratedProtocolMessageType('DumpMisoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DUMPMISOREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.DumpMisoRequest)
  })
_sym_db.RegisterMessage(DumpMisoRequest)

SinapsStatusRegisters = _reflection.GeneratedProtocolMessageType('SinapsStatusRegisters', (_message.Message,), {
  'DESCRIPTOR' : _SINAPSSTATUSREGISTERS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.SinapsStatusRegisters)
  })
_sym_db.RegisterMessage(SinapsStatusRegisters)

HALdashboard = _reflection.GeneratedProtocolMessageType('HALdashboard', (_message.Message,), {
  'DESCRIPTOR' : _HALDASHBOARD,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.HALdashboard)
  })
_sym_db.RegisterMessage(HALdashboard)

StimParams = _reflection.GeneratedProtocolMessageType('StimParams', (_message.Message,), {
  'DESCRIPTOR' : _STIMPARAMS,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.StimParams)
  })
_sym_db.RegisterMessage(StimParams)

StimParamsReply = _reflection.GeneratedProtocolMessageType('StimParamsReply', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STIMPARAMSREPLY_PARAMSENTRY,
    '__module__' : 'allegoserver_pb2'
    # @@protoc_insertion_point(class_scope:allego.StimParamsReply.ParamsEntry)
    })
  ,
  'DESCRIPTOR' : _STIMPARAMSREPLY,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.StimParamsReply)
  })
_sym_db.RegisterMessage(StimParamsReply)
_sym_db.RegisterMessage(StimParamsReply.ParamsEntry)

ManualStimTriggerRequest = _reflection.GeneratedProtocolMessageType('ManualStimTriggerRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANUALSTIMTRIGGERREQUEST,
  '__module__' : 'allegoserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManualStimTriggerRequest)
  })
_sym_db.RegisterMessage(ManualStimTriggerRequest)


DESCRIPTOR._options = None
_STIMPARAMSREPLY_PARAMSENTRY._options = None

_ALLEGOCORE = _descriptor.ServiceDescriptor(
  name='AllegoCore',
  full_name='allego.AllegoCore',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7414,
  serialized_end=12248,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.AllegoCore.Healthcheck',
    index=0,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Restart',
    full_name='allego.AllegoCore.Restart',
    index=1,
    containing_service=None,
    input_type=_RESTARTREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Close',
    full_name='allego.AllegoCore.Close',
    index=2,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetRadixEnvironment',
    full_name='allego.AllegoCore.GetRadixEnvironment',
    index=3,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._RADIXENVIRONMENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WorkspaceControl',
    full_name='allego.AllegoCore.WorkspaceControl',
    index=4,
    containing_service=None,
    input_type=common__pb2._WORKSPACECONTROLREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetRadiensServers',
    full_name='allego.AllegoCore.GetRadiensServers',
    index=5,
    containing_service=None,
    input_type=common__pb2._GETRADIENSSERVERSREQUEST,
    output_type=common__pb2._RADIENSSERVERSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStatusPollFieldsToUpdate',
    full_name='allego.AllegoCore.GetStatusPollFieldsToUpdate',
    index=6,
    containing_service=None,
    input_type=common__pb2._STATUSPOLLFIELDSTOUPDATEREQUEST,
    output_type=common__pb2._STATUSPOLLFIELDSTOUPDATE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigCore',
    full_name='allego.AllegoCore.SetConfigCore',
    index=7,
    containing_service=None,
    input_type=_SETCONFIGCOREREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileState',
    full_name='allego.AllegoCore.SetProfileState',
    index=8,
    containing_service=None,
    input_type=_SETPROFILEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigRecording',
    full_name='allego.AllegoCore.SetConfigRecording',
    index=9,
    containing_service=None,
    input_type=_CONFIGRECORDING,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetStreamState',
    full_name='allego.AllegoCore.SetStreamState',
    index=10,
    containing_service=None,
    input_type=_SETSTREAMREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetRecordState',
    full_name='allego.AllegoCore.SetRecordState',
    index=11,
    containing_service=None,
    input_type=_SETRECORDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDIOEvents',
    full_name='allego.AllegoCore.SetDIOEvents',
    index=12,
    containing_service=None,
    input_type=_DIOMODEEVENTSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDIOManual',
    full_name='allego.AllegoCore.SetDIOManual',
    index=13,
    containing_service=None,
    input_type=_DIOMODEMANUALREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDIOGated',
    full_name='allego.AllegoCore.SetDIOGated',
    index=14,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDACGain',
    full_name='allego.AllegoCore.SetDACGain',
    index=15,
    containing_service=None,
    input_type=_DACGAINREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDACStream',
    full_name='allego.AllegoCore.SetDACStream',
    index=16,
    containing_service=None,
    input_type=common__pb2._DACSTREAMREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDACOff',
    full_name='allego.AllegoCore.SetDACOff',
    index=17,
    containing_service=None,
    input_type=common__pb2._DACOFFREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSimPorts',
    full_name='allego.AllegoCore.SetSimPorts',
    index=18,
    containing_service=None,
    input_type=_SETSIMPORTSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetMuxChannel',
    full_name='allego.AllegoCore.SetMuxChannel',
    index=19,
    containing_service=None,
    input_type=_SETMUXCHANNELREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetTriggerMode',
    full_name='allego.AllegoCore.SetTriggerMode',
    index=20,
    containing_service=None,
    input_type=_TRIGGERMODESTATE,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPotVoltage',
    full_name='allego.AllegoCore.SetPotVoltage',
    index=21,
    containing_service=None,
    input_type=_SETPOTVOLTAGEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPotRange',
    full_name='allego.AllegoCore.SetPotRange',
    index=22,
    containing_service=None,
    input_type=_SETPOTRANGEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPotMode',
    full_name='allego.AllegoCore.SetPotMode',
    index=23,
    containing_service=None,
    input_type=_SETPOTMODEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPotCellEnable',
    full_name='allego.AllegoCore.SetPotCellEnable',
    index=24,
    containing_service=None,
    input_type=_SETPOTCELLENABLEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSPGroup',
    full_name='allego.AllegoCore.SetDSPGroup',
    index=25,
    containing_service=None,
    input_type=common__pb2._SETDSPGROUPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetStimParams',
    full_name='allego.AllegoCore.SetStimParams',
    index=26,
    containing_service=None,
    input_type=_STIMPARAMS,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStimParams',
    full_name='allego.AllegoCore.GetStimParams',
    index=27,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_STIMPARAMSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManualStimTrigger',
    full_name='allego.AllegoCore.ManualStimTrigger',
    index=28,
    containing_service=None,
    input_type=_MANUALSTIMTRIGGERREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='allego.AllegoCore.GetConfig',
    index=29,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_CONFIGCORE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkspace',
    full_name='allego.AllegoCore.GetWorkspace',
    index=30,
    containing_service=None,
    input_type=common__pb2._GETWORKSPACEREQUEST,
    output_type=common__pb2._GETWORKSPACEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigRecording',
    full_name='allego.AllegoCore.GetConfigRecording',
    index=31,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_CONFIGRECORDING,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='allego.AllegoCore.GetStatus',
    index=32,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_BACKBONESTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigAndStatus',
    full_name='allego.AllegoCore.GetConfigAndStatus',
    index=33,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_CONFIGANDSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSourceParams',
    full_name='allego.AllegoCore.GetDataSourceParams',
    index=34,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=datasource__pb2._DATASOURCEPARAMS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIntanImpedance',
    full_name='allego.AllegoCore.GetIntanImpedance',
    index=35,
    containing_service=None,
    input_type=datasource__pb2._IMPEDANCEREQUEST,
    output_type=datasource__pb2._IMPEDANCE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDSPGroup',
    full_name='allego.AllegoCore.GetDSPGroup',
    index=36,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._DSPGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDIOReg',
    full_name='allego.AllegoCore.GetDIOReg',
    index=37,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_DIGITALOUTREGISTER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDACReg',
    full_name='allego.AllegoCore.GetDACReg',
    index=38,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_ANALOGOUTREGISTER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSerial',
    full_name='allego.AllegoCore.GetSerial',
    index=39,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_SERIALNUMBER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTriggerMode',
    full_name='allego.AllegoCore.GetTriggerMode',
    index=40,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_TRIGGERMODESTATE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetADCLevel',
    full_name='allego.AllegoCore.GetADCLevel',
    index=41,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_GETADCLEVELREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReadWireOut',
    full_name='allego.AllegoCore.ReadWireOut',
    index=42,
    containing_service=None,
    input_type=_READWIREOUTREQUEST,
    output_type=_READWIREOUTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListSensorSpecs',
    full_name='allego.AllegoCore.ListSensorSpecs',
    index=43,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._LISTSENSORSPECSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignalGroupIDs',
    full_name='allego.AllegoCore.GetSignalGroupIDs',
    index=44,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._GETSIGNALGROUPIDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSpikeSorterIDs',
    full_name='allego.AllegoCore.GetSpikeSorterIDs',
    index=45,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=spikesorter__pb2._GETSPIKESORTERIDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignalGroup',
    full_name='allego.AllegoCore.GetSignalGroup',
    index=46,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._SIGNALGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSignalGroup',
    full_name='allego.AllegoCore.UpdateSignalGroup',
    index=47,
    containing_service=None,
    input_type=common__pb2._UPDATESIGNALGROUPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ScanPorts',
    full_name='allego.AllegoCore.ScanPorts',
    index=48,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._SIGNALGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSensor',
    full_name='allego.AllegoCore.SetSensor',
    index=49,
    containing_service=None,
    input_type=common__pb2._SETSENSORREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSensorPositionTcs',
    full_name='allego.AllegoCore.SetSensorPositionTcs',
    index=50,
    containing_service=None,
    input_type=common__pb2._SETSENSORPOSITIONTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSitePositionsTcs',
    full_name='allego.AllegoCore.SetSitePositionsTcs',
    index=51,
    containing_service=None,
    input_type=common__pb2._SETSITEPOSITIONSTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSourceStatus',
    full_name='allego.AllegoCore.GetDataSourceStatus',
    index=52,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=datasource__pb2._DATASOURCESTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureStart',
    full_name='allego.AllegoCore.FeatureStart',
    index=53,
    containing_service=None,
    input_type=common__pb2._FEATURESTARTSTOPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureStop',
    full_name='allego.AllegoCore.FeatureStop',
    index=54,
    containing_service=None,
    input_type=common__pb2._FEATURESTARTSTOPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPrivacy',
    full_name='allego.AllegoCore.GetPrivacy',
    index=55,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._PRIVACYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPrivacy',
    full_name='allego.AllegoCore.SetPrivacy',
    index=56,
    containing_service=None,
    input_type=common__pb2._SETPRIVACYREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadAllMosi',
    full_name='allego.AllegoCore.LoadAllMosi',
    index=57,
    containing_service=None,
    input_type=_LOADALLMOSIREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TransmitMosi',
    full_name='allego.AllegoCore.TransmitMosi',
    index=58,
    containing_service=None,
    input_type=_TRANSMITMOSIREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DumpMiso',
    full_name='allego.AllegoCore.DumpMiso',
    index=59,
    containing_service=None,
    input_type=_DUMPMISOREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSinapsStatusRegisters',
    full_name='allego.AllegoCore.GetSinapsStatusRegisters',
    index=60,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_SINAPSSTATUSREGISTERS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrCreateEventViewer',
    full_name='allego.AllegoCore.GetOrCreateEventViewer',
    index=61,
    containing_service=None,
    input_type=common__pb2._EVENTVIEWERID,
    output_type=common__pb2._EVENTVIEWERCONFIG,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEventViewer',
    full_name='allego.AllegoCore.UpdateEventViewer',
    index=62,
    containing_service=None,
    input_type=common__pb2._EVENTVIEWERCONFIG,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventViewerEvents',
    full_name='allego.AllegoCore.ListEventViewerEvents',
    index=63,
    containing_service=None,
    input_type=common__pb2._EVENTVIEWERID,
    output_type=common__pb2._LISTEVENTVIEWEREVENTSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetEventViewerEvent',
    full_name='allego.AllegoCore.GetEventViewerEvent',
    index=64,
    containing_service=None,
    input_type=common__pb2._GETEVENTVIEWEREVENTREQUEST,
    output_type=common__pb2._EVENTVIEWEREVENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventViewers',
    full_name='allego.AllegoCore.ListEventViewers',
    index=65,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._LISTEVENTVIEWERSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHALdashboard',
    full_name='allego.AllegoCore.GetHALdashboard',
    index=66,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=_HALDASHBOARD,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ALLEGOCORE)

DESCRIPTOR.services_by_name['AllegoCore'] = _ALLEGOCORE


_PCACHE1 = _descriptor.ServiceDescriptor(
  name='Pcache1',
  full_name='allego.Pcache1',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=12251,
  serialized_end=12605,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.Pcache1.Healthcheck',
    index=0,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHDSnapshot',
    full_name='allego.Pcache1.GetHDSnapshot',
    index=1,
    containing_service=None,
    input_type=common__pb2._HDSNAPSHOTREQUEST,
    output_type=common__pb2._HDSNAPSHOT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHDSnapshotFromHead',
    full_name='allego.Pcache1.GetHDSnapshotFromHead',
    index=2,
    containing_service=None,
    input_type=common__pb2._HDSNAPSHOTREQUEST,
    output_type=common__pb2._HDSNAPSHOT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignals',
    full_name='allego.Pcache1.GetSignals',
    index=3,
    containing_service=None,
    input_type=common__pb2._GETSIGNALSREQUEST,
    output_type=common__pb2._RAWSIGNALS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetTimeRangeToHead',
    full_name='allego.Pcache1.SetTimeRangeToHead',
    index=4,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PCACHE1)

DESCRIPTOR.services_by_name['Pcache1'] = _PCACHE1


_KPI1 = _descriptor.ServiceDescriptor(
  name='Kpi1',
  full_name='allego.Kpi1',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=12608,
  serialized_end=12824,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.Kpi1.Healthcheck',
    index=0,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KpiGetMetrics',
    full_name='allego.Kpi1.KpiGetMetrics',
    index=1,
    containing_service=None,
    input_type=common__pb2._KPIMETRICSREQ,
    output_type=common__pb2._KPIBUNDLEPACKETMETRICS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetKpiStatus',
    full_name='allego.Kpi1.GetKpiStatus',
    index=2,
    containing_service=None,
    input_type=common__pb2._GETKPISTATUSREQUEST,
    output_type=common__pb2._KPISTATUSREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_KPI1)

DESCRIPTOR.services_by_name['Kpi1'] = _KPI1


_NEURONS1 = _descriptor.ServiceDescriptor(
  name='Neurons1',
  full_name='allego.Neurons1',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  serialized_start=12827,
  serialized_end=14045,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.Neurons1.Healthcheck',
    index=0,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterCommand',
    full_name='allego.Neurons1.SpikeSorterCommand',
    index=1,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERCOMMANDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterSetParam',
    full_name='allego.Neurons1.SpikeSorterSetParam',
    index=2,
    containing_service=None,
    input_type=common__pb2._SPIKESORTERSETPARAMREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterSetParams',
    full_name='allego.Neurons1.SpikeSorterSetParams',
    index=3,
    containing_service=None,
    input_type=common__pb2._SPIKESORTERSETPARAMSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetParam',
    full_name='allego.Neurons1.SpikeSorterGetParam',
    index=4,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._GETSPIKESORTERPARAMCOMMANDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetState',
    full_name='allego.Neurons1.SpikeSorterGetState',
    index=5,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERSTATE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetDashboard',
    full_name='allego.Neurons1.SpikeSorterGetDashboard',
    index=6,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERGETDASHBOARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetRasterData',
    full_name='allego.Neurons1.SpikeSorterGetRasterData',
    index=7,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERGETRASTERDATAREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERRASTERDATAREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceGetSpikesDense',
    full_name='allego.Neurons1.BiointerfaceGetSpikesDense',
    index=8,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEGETSPIKESREQUEST,
    output_type=biointerface__pb2._BIOINTERFACESPIKEDATADENSEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceGetNeurons',
    full_name='allego.Neurons1.BiointerfaceGetNeurons',
    index=9,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEGETNEURONSREQUEST,
    output_type=biointerface__pb2._BIOINTERFACEGETNEURONSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceSeekEndSpikeTimestamps',
    full_name='allego.Neurons1.BiointerfaceSeekEndSpikeTimestamps',
    index=10,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetSpec',
    full_name='allego.Neurons1.SpikesGetSpec',
    index=11,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=biointerface__pb2._SPIKESSPECREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceViz',
    full_name='allego.Neurons1.BiointerfaceViz',
    index=12,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEVIZREQUEST,
    output_type=biointerface__pb2._BIOINTERFACEVIZREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NEURONS1)

DESCRIPTOR.services_by_name['Neurons1'] = _NEURONS1

# @@protoc_insertion_point(module_scope)
